//Source file: CallInfoReport.java
//Date: December 2004
//Generic Call Control Data Types for 3GPP TS 29.198-04-2 V6.3.0

package org.csapi.jr.se.cc.gccs;

/**
 * Defines the Sequence of Data Elements that specify the call information requested. Information that was not requested is invalid. 
A callInfoReport will be generated at the end of user interaction and at the end of the connection with the associated address. This means that either the destination related information is present or the resource related information, but not both.
 * 
 */
public final class CallInfoReport implements java.io.Serializable {

    private int callInfoType;
    private String callInitiationStartTime;
    private String callConnectedToResourceTime;
    private String callConnectedToDestinationTime;
    private String callEndTime;
    private org.csapi.jr.se.cc.gccs.CallReleaseCause cause;

    /**
     * Creates a new CallInfoReport instance.
     */
    public CallInfoReport () {}

    /**
     * Creates a new CallInfoReport instance.
     * @param _callInfoType   The type of call report.
     * @param _callInitiationStartTime   The time and date when the call, or follow-on call, was started as a result of a routeReq.
     * @param _callConnectedToResourceTime   The date and time when the call was connected to the resource.
This data element is only valid when information on user interaction is reported.
     * @param _callConnectedToDestinationTime   The date and time when the call was connected to the destination (that is when the destination answered the call). 
If the destination did not answer, the time is set to an empty string.
This data element is invalid when information on user interaction is reported.
     * @param _callEndTime   The date and time when the call or follow-on call or user interaction was terminated.
     * @param _cause   The cause of the termination.
     */
    public CallInfoReport (int _callInfoType, String _callInitiationStartTime, String _callConnectedToResourceTime, String _callConnectedToDestinationTime, String _callEndTime, org.csapi.jr.se.cc.gccs.CallReleaseCause _cause) {

        this.callInfoType = _callInfoType;
        this.callInitiationStartTime = _callInitiationStartTime;
        this.callConnectedToResourceTime = _callConnectedToResourceTime;
        this.callConnectedToDestinationTime = _callConnectedToDestinationTime;
        this.callEndTime = _callEndTime;
        this.cause = _cause;
    }

    /**
     * This method returns a callInfoType.
     * 
     * @return a int value
     */
    public int getCallInfoType() {
        return callInfoType;
    }

    /**
     * This method returns a callInitiationStartTime.
     * 
     * @return a String value
     */
    public String getCallInitiationStartTime() {
        return callInitiationStartTime;
    }

    /**
     * This method returns a callConnectedToResourceTime.
     * 
     * @return a String value
     */
    public String getCallConnectedToResourceTime() {
        return callConnectedToResourceTime;
    }

    /**
     * This method returns a callConnectedToDestinationTime.
     * 
     * @return a String value
     */
    public String getCallConnectedToDestinationTime() {
        return callConnectedToDestinationTime;
    }

    /**
     * This method returns a callEndTime.
     * 
     * @return a String value
     */
    public String getCallEndTime() {
        return callEndTime;
    }

    /**
     * This method returns a cause.
     * 
     * @return a org.csapi.jr.se.cc.gccs.CallReleaseCause value
     */
    public org.csapi.jr.se.cc.gccs.CallReleaseCause getCause() {
        return cause;
    }


    /**
     * This method sets a callInfoType.
     */ 
    public void setCallInfoType(int callInfoType) {
        this.callInfoType = callInfoType;
    }

    /**
     * This method sets a callInitiationStartTime.
     */ 
    public void setCallInitiationStartTime(String callInitiationStartTime) {
        this.callInitiationStartTime = callInitiationStartTime;
    }

    /**
     * This method sets a callConnectedToResourceTime.
     */ 
    public void setCallConnectedToResourceTime(String callConnectedToResourceTime) {
        this.callConnectedToResourceTime = callConnectedToResourceTime;
    }

    /**
     * This method sets a callConnectedToDestinationTime.
     */ 
    public void setCallConnectedToDestinationTime(String callConnectedToDestinationTime) {
        this.callConnectedToDestinationTime = callConnectedToDestinationTime;
    }

    /**
     * This method sets a callEndTime.
     */ 
    public void setCallEndTime(String callEndTime) {
        this.callEndTime = callEndTime;
    }

    /**
     * This method sets a cause.
     */ 
    public void setCause(org.csapi.jr.se.cc.gccs.CallReleaseCause cause) {
        this.cause = cause;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallInfoReport)) {
            return false;
        } 
        CallInfoReport callInfoReport = (CallInfoReport) o;
        if(!(this.callInfoType == callInfoReport.callInfoType))  {
            return false;
        }
        if(!(this.callInitiationStartTime == callInfoReport.callInitiationStartTime))  {
            return false;
        }
        if(!(this.callConnectedToResourceTime == callInfoReport.callConnectedToResourceTime))  {
            return false;
        }
        if(!(this.callConnectedToDestinationTime == callInfoReport.callConnectedToDestinationTime))  {
            return false;
        }
        if(!(this.callEndTime == callInfoReport.callEndTime))  {
            return false;
        }
        if ((this.cause != null) && (callInfoReport.cause != null)) {
            if(!(this.cause.equals(callInfoReport.cause))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallInfoReport

