//Source file: CallNotification.java
//Date: December 2004
//Generic Call Control Interfaces for 3GPP TS 29.198-04-2 V6.3.0

package org.csapi.jr.se.cc.gccs;

/**
 * This interface represents a CallNotification activity object.<BR>
 *
 */
public interface CallNotification extends org.csapi.jr.se.Activity {

    /**
     * Returns a reference to the CallControlManager responsible for creation of the CallNotification.
     *
     * @return  A reference to the CallControlManager responsible for creation of the CallNotification.
     */
    org.csapi.jr.se.cc.gccs.CallControlManager getCallControlManager();

    /**
     * Adds a CallNotificationListener which is interested in events generated by the CallNotification.
     *
     * @param  callNotificationListener  A reference to the CallNotificationListener which is to be added as
     *        a listener.
     */
    void addCallNotificationListener(org.csapi.jr.se.cc.gccs.CallNotificationListener callNotificationListener);

    /**
     * Removes a CallNotificationListener which is no longer interested events generated by the CallNotification.
     *
     * @param  callNotificationListener  A reference to the CallNotificationListener which is to be removed as
     *        a listener.
     */
    void removeCallNotificationListener(org.csapi.jr.se.cc.gccs.CallNotificationListener callNotificationListener);

    /**
     * Invokes the enableCallNotification() method on the Parlay Gateway.
     */
    void enableCallNotification(
           org.csapi.jr.se.cc.gccs.CallEventCriteria eventCriteria)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidInterfaceTypeException,
       org.csapi.jr.se.InvalidEventTypeException;

    /**
     * Invokes the disableCallNotification() method on the Parlay Gateway.
     */
    void disableCallNotification()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the changeCallNotification() method on the Parlay Gateway.
     */
    void changeCallNotification(
           org.csapi.jr.se.cc.gccs.CallEventCriteria eventCriteria)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidEventTypeException;
}
